summaryrefslogtreecommitdiffstats
path: root/src/gui.c
diff options
context:
space:
mode:
authorBram Moolenaar <Bram@vim.org>2005-04-24 21:59:46 +0000
committerBram Moolenaar <Bram@vim.org>2005-04-24 21:59:46 +0000
commit41bfd309b8a9d1b58aa599ba71b236aff1d74a47 (patch)
tree4a22c7bb98e9b8e06f693262e28314aae36efdd8 /src/gui.c
parent6f3058f6b467e4ee74a8487e444936f63fa1efa4 (diff)
updated for version 7.0071
Diffstat (limited to 'src/gui.c')
-rw-r--r--src/gui.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/gui.c b/src/gui.c
index 54804f71c0..8cd43ac8f9 100644
--- a/src/gui.c
+++ b/src/gui.c
@@ -539,12 +539,15 @@ gui_init()
/* Our GUI can't do bidi. */
p_tbidi = FALSE;
#endif
-#if defined FEAT_GUI_GTK || defined FEAT_GUI_KDE
+#if defined(FEAT_GUI_GTK) || defined(FEAT_GUI_KDE)
/* Give GTK+ a chance to put all widget's into place. */
gui_mch_update();
/* Now make sure the shell fits on the screen. */
gui_set_shellsize(FALSE, TRUE);
#endif
+ /* When 'lines' was set while starting up the topframe may have to be
+ * resized. */
+ win_new_shellsize();
#ifdef FEAT_BEVAL
/* Always create the Balloon Evaluation area, but disable it when
@@ -4181,8 +4184,8 @@ gui_mouse_moved(x, y)
/*
* format a mouse click on status line input
* ala gui_send_mouse_event(0, x, y, 0, 0);
* Trick: Use a column of -1, so that check_termcode will generate a
* K_LEFTMOUSE_NM key code.
*/
if (finish_op)
{
@@ -4196,7 +4199,7 @@ gui_mouse_moved(x, y)
st[3] = (char_u)MOUSE_LEFT;
fill_mouse_coord(st + 4,
#ifdef FEAT_VERTSPLIT
- W_WINCOL(wp),
+ wp->w_wincol == 0 ? -1 : wp->w_wincol + MOUSE_COLOFF,
#else
-1,
#endif
@@ -4181,8 +4184,8 @@ gui_mouse_moved(x, y)
* format a mouse click on status line input
* ala gui_send_mouse_event(0, x, y, 0, 0);
- * Trick: Use a column of -1, so that check_termcode will generate a
- * K_LEFTMOUSE_NM key code.
+ * Trick: Use a column number -1, so that get_pseudo_mouse_code() will
+ * generate a K_LEFTMOUSE_NM key code.
*/
if (finish_op)